@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2008 QoSient, LLC
+ * Copyright (c) 2000-2012 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -66,9 +66,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus-3.0/clients/common/argus_auth.c#9 $
- * $DateTime: 2006/04/03 21:20:59 $
- * $Change: 810 $
+ * $Id: //depot/argus-3.0.6/clients/common/argus_auth.c#1 $
+ * $DateTime: 2012/04/17 12:22:02 $
+ * $Change: 2368 $
  */
 
 
@@ -76,23 +76,27 @@
 #define ArgusAuth
 #endif
 
+#ifdef HAVE_CONFIG_H
+#include "argus_config.h"
+#endif
+
 #include <stdlib.h>
 #include <unistd.h>
 
 #include <errno.h>
 
-#include <compat.h>
+#include <argus_compat.h>
 
 #include <netinet/in.h>
 #include <string.h>
 
 #include <syslog.h>
 
-#ifdef ARGUS_SASL
-
 #include <ctype.h>
 #include <assert.h>
 #include <netdb.h>
+
+#ifdef ARGUS_SASL
 #include <sasl/sasl.h>
 #include <sasl/saslutil.h>
 
@@ -651,6 +655,7 @@ RaGetSaslString (int fd, char *buf, int buflen)
    return len;
 }
 
+#endif /* ARGUS_SASL */
 
 int
 iptostring(const struct sockaddr *addr, socklen_t addrlen, char *out, unsigned outlen)
@@ -683,4 +688,3 @@ iptostring(const struct sockaddr *addr, socklen_t addrlen, char *out, unsigned o
     return 0;
 }
 
-#endif /* ARGUS_SASL */
