@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2008 QoSient, LLC
+ * Copyright (c) 2000-2012 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,12 +28,15 @@
  */
  
 /*
- * $Id: //depot/gargoyle/gargoyle-4.0/clients/common/argus_event.c#14 $
- * $DateTime: 2007/02/09 14:33:28 $
- * $Change: 1033 $
+ * $Id: //depot/argus-3.0.6/clients/common/argus_event.c#1 $
+ * $DateTime: 2012/04/17 12:22:02 $
+ * $Change: 2368 $
  */
  
 
+#ifdef HAVE_CONFIG_H
+#include "argus_config.h"
+#endif
 #define ARGUS_EVENT_PROC		1
 #if defined(CYGWIN)
 #define USE_IPV6
@@ -128,13 +131,13 @@ char *RaSQLFieldType [RATOTALSQLOBJECTS] = {
    "varchar(16) not null",
 };
 
-struct ArgusEventStruct *
+struct ArgusEventObject *
 ArgusNewEvent(struct ArgusParserStruct *parser, int target, int type, int cause,
                      int facility, int severity, char *accounts, char *message, char *metadata)
 {
-   struct ArgusEventStruct *retn = NULL;
+   struct ArgusEventObject *retn = NULL;
 
-   if ((retn = (struct ArgusEventStruct *) calloc(1, sizeof (*retn))) != NULL) {
+   if ((retn = (struct ArgusEventObject *) calloc(1, sizeof (*retn))) != NULL) {
       retn->target   = target;
       retn->type     = type;
       retn->cause    = cause;
@@ -155,7 +158,7 @@ ArgusNewEvent(struct ArgusParserStruct *parser, int target, int type, int cause,
 }
 
 void
-ArgusDeleteEvent(struct ArgusEventStruct *event)
+ArgusDeleteEvent(struct ArgusEventObject *event)
 {
    if (event->accounts)
       free (event->accounts);
@@ -172,13 +175,13 @@ ArgusDeleteEvent(struct ArgusEventStruct *event)
 }
 
 
-int ArgusProcessSQLEvent (struct ArgusParserStruct *, struct ArgusEventStruct *, struct ArgusRecordStruct *);
-int ArgusProcessSyslogEvent (struct ArgusParserStruct *, struct ArgusEventStruct *, struct ArgusRecordStruct *);
-int ArgusProcessFileEvent (struct ArgusParserStruct *, struct ArgusEventStruct *, struct ArgusRecordStruct *);
-int ArgusProcessTermEvent (struct ArgusParserStruct *, struct ArgusEventStruct *, struct ArgusRecordStruct *);
+int ArgusProcessSQLEvent (struct ArgusParserStruct *, struct ArgusEventObject *, struct ArgusRecordStruct *);
+int ArgusProcessSyslogEvent (struct ArgusParserStruct *, struct ArgusEventObject *, struct ArgusRecordStruct *);
+int ArgusProcessFileEvent (struct ArgusParserStruct *, struct ArgusEventObject *, struct ArgusRecordStruct *);
+int ArgusProcessTermEvent (struct ArgusParserStruct *, struct ArgusEventObject *, struct ArgusRecordStruct *);
 
 int
-ArgusProcessEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *event, struct ArgusRecordStruct *ns)
+ArgusProcessEvent (struct ArgusParserStruct *parser, struct ArgusEventObject *event, struct ArgusRecordStruct *ns)
 {
    int retn = 0, i, x;
 
@@ -195,7 +198,7 @@ ArgusProcessEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *ev
 
          while ((ptr = strchr (tptr, '$')) != NULL) {
             *ptr++ = '\0';
-            sprintf (&resultbuf[strlen(resultbuf)], tptr);
+            sprintf (&resultbuf[strlen(resultbuf)], "%s", tptr);
  
             for (i = 0, x = 0; x < MAX_PRINT_ALG_TYPES; x++) {
                if (!strncmp (RaPrintAlgorithmTable[x].field, ptr, strlen(RaPrintAlgorithmTable[x].field))) {
@@ -227,13 +230,13 @@ ArgusProcessEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *ev
          event->metadata = strdup(resultbuf);
       }
        
-      for (i = 1; i < (NTAIS_ETARGETS + 1); i++) {
+      for (i = 1; i < (AIS_ETARGETS + 1); i++) {
          if (event->target & (0x01 << (i - 1))) {
             switch ((0x01 << (i - 1))) {
-               case NTAIS_DATABASE: retn = ArgusProcessSQLEvent(parser, event, ns); break;
-               case NTAIS_SYSLOG :  retn = ArgusProcessSyslogEvent(parser, event, ns); break;
-               case NTAIS_FILE:     retn = ArgusProcessFileEvent(parser, event, ns); break;
-               case NTAIS_TERM:     retn = ArgusProcessTermEvent(parser, event, ns); break;
+               case AIS_DATABASE: retn = ArgusProcessSQLEvent(parser, event, ns); break;
+               case AIS_SYSLOG :  retn = ArgusProcessSyslogEvent(parser, event, ns); break;
+               case AIS_FILE:     retn = ArgusProcessFileEvent(parser, event, ns); break;
+               case AIS_TERM:     retn = ArgusProcessTermEvent(parser, event, ns); break;
                default:  break;
             }
 
@@ -251,14 +254,14 @@ ArgusProcessEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *ev
 
 
 int
-ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *event, struct ArgusRecordStruct *ns)
+ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventObject *event, struct ArgusRecordStruct *ns)
 {
-   char *RaProject = NULL, *RaHost = NULL, *RaUser = NULL;
+   char *RaDatabase = NULL, *RaHost = NULL, *RaUser = NULL;
    char *RaPass = NULL, *RaTable = NULL;
    char *ArgusEventTableName = NULL;
-   char sbuf[MAXSTRLEN], rbuf[MAXSTRLEN];
-   char mbuf[MAXSTRLEN], username[1024], *uid; 
+   char sbuf[MAXSTRLEN], mbuf[MAXSTRLEN], username[1024], *uid; 
    char userbuf[MAXSTRLEN], *sptr, *hptr; 
+   char rbuf[ARGUS_MAXRECORDSIZE];
    char *ptr, *aname, *accounts = NULL;
    struct ArgusRecord *argus = NULL;
    char stim[128], etim[128];
@@ -280,23 +283,23 @@ ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
    if ((RaPass == NULL) && (ArgusParser->dbpstr != NULL))
       RaPass = ArgusParser->dbpstr;
  
-   if ((RaProject == NULL) && (ArgusParser->projstr != NULL))
-      RaProject = ArgusParser->projstr;
+   if ((RaDatabase == NULL) && (ArgusParser->writeDbstr != NULL))
+      RaDatabase = ArgusParser->writeDbstr;
  
-   if (RaProject == NULL)
-      ArgusLog(LOG_ERR, "must specify project (-P option)");
+   if (RaDatabase == NULL)
+      ArgusLog(LOG_ERR, "must specify database");
  
-   if ((hptr = strchr (RaProject, '@')) != NULL) {
+   if ((hptr = strchr (RaDatabase, '@')) != NULL) {
       *hptr++ = '\0';
       RaHost = hptr;
    }
  
-   if ((ptr = strchr (RaProject, ':')) != NULL) {
+   if ((ptr = strchr (RaDatabase, ':')) != NULL) {
       *ptr++ = '\0';
       RaTable = ptr;
    }
 
-   sprintf (sbuf, "%s_Events", RaProject);
+   sprintf (sbuf, "%s_Events", RaDatabase);
    ArgusEventTableName = strdup(sbuf);
 
    bzero((char *)RaExistTableNames, sizeof(RaExistTableNames));
@@ -385,13 +388,16 @@ ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
    } else
       ArgusLog(LOG_ERR, "mysql_init error %s", mysql_error(&mysql));
 
-   if (event->type & (NTAIS_EVENT | NTAIS_CONDITION)) {
+   if (event->type & (AIS_EVENT | AIS_CONDITION)) {
       if (ns != NULL) {
-         if ((ns->canon.time.src.start.tv_sec  == ns->canon.time.src.start.tv_sec) &&
-             (ns->canon.time.src.start.tv_usec == ns->canon.time.src.start.tv_usec)) {
-            event->type |= NTAIS_EVENT;
-         } else {
-            event->type |= NTAIS_CONDITION;
+         struct ArgusTimeObject *time = (void *) ns->dsrs[ARGUS_TIME_INDEX];
+         if (time != NULL) {
+            if ((time->src.start.tv_sec  == time->src.start.tv_sec) &&
+                (time->src.start.tv_usec == time->src.start.tv_usec)) {
+               event->type |= AIS_EVENT;
+            } else {
+               event->type |= AIS_CONDITION;
+            }
          }
       }
    }
@@ -447,7 +453,7 @@ ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
       int i, seen;
 
       bzero(types, MAXSTRLEN);
-      for (i = 0, seen = 0; i < NTAIS_NTYPES; i++) {
+      for (i = 0, seen = 0; i < AIS_NTYPES; i++) {
          if (event->type & (0x01 << i)) {
             if (seen) sprintf (&types[strlen(types)], "|");
             sprintf (&types[strlen(types)], "%s", RaSQLEventTypes[i].s);
@@ -479,15 +485,18 @@ ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
    bzero(etim, sizeof(etim));
 
    if (ns == NULL) {
-      if ((stvp.tv_sec = parser->startime_t) == 0x7FFFFFFF)
+      if ((stvp.tv_sec = parser->startime_t.tv_sec) == 0x7FFFFFFF)
          gettimeofday(&stvp, 0L);
 
-      if ((etvp.tv_sec  = parser->lasttime_t) == 0)
+      if ((etvp.tv_sec  = parser->lasttime_t.tv_sec) == 0)
          gettimeofday(&etvp, 0L);
 
    } else {
-      stvp.tv_sec = ns->canon.time.src.start.tv_sec;
-      etvp.tv_sec = ns->canon.time.src.end.tv_sec;
+      struct ArgusTimeObject *time = (void *) ns->dsrs[ARGUS_TIME_INDEX];
+      if (time != NULL) {
+         stvp.tv_sec = time->src.start.tv_sec;
+         etvp.tv_sec = time->src.end.tv_sec;
+      }
    }
 
    ArgusPrintTime (parser, stim, &stvp);
@@ -507,12 +516,12 @@ ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
    if (argus != NULL) {
       sprintf (sbuf, "INSERT %s (project, start, end, type, cause, facility, severity, version, message, metadata, status, record) VALUES ", ArgusEventTableName);
       sprintf (&sbuf[strlen(sbuf)], "(\"%s\", \"%s\", \"%s\", %d, %d, %d, %d, \"%s\", \"%s\", \"%s\", %d, \"%s\")",
-               RaProject, stim, etim, event->type, event->cause, event->facility, 
+               RaDatabase, stim, etim, event->type, event->cause, event->facility, 
                event->severity, version, event->message, event->metadata, 0, mbuf);
    } else {
       sprintf (sbuf, "INSERT %s (project, start, end, type, cause, facility, severity, version, message, metadata, status) VALUES ", ArgusEventTableName);
       sprintf (&sbuf[strlen(sbuf)], "(\"%s\", \"%s\", \"%s\", %d, %d, %d, %d, \"%s\", \"%s\", \"%s\", %d)",
-               RaProject, stim, etim, event->type, event->cause, event->facility, 
+               RaDatabase, stim, etim, event->type, event->cause, event->facility, 
                event->severity, version, event->message, event->metadata, 0);
    }
 
@@ -536,17 +545,17 @@ ArgusProcessSQLEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
 
 
 int
-ArgusProcessSyslogEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *event, struct ArgusRecordStruct *ns)
+ArgusProcessSyslogEvent (struct ArgusParserStruct *parser, struct ArgusEventObject *event, struct ArgusRecordStruct *ns)
 {
    int retn = 0, logopt = LOG_PID, i;
    char sbuf[MAXSTRLEN];
    char *facility;
 
-   for (i = 0; i < NTAIS_NFACILITY; i++)
+   for (i = 0; i < AIS_NFACILITY; i++)
       if (RaSQLEventFacilities[i].v == event->facility)
          facility = RaSQLEventFacilities[i].s;
 
-   sprintf (sbuf, "[ntais] %s:%s:'%s' ", facility, event->metadata, event->message);
+   sprintf (sbuf, "[ais] %s:%s:'%s' ", facility, event->metadata, event->message);
 
    if (ns != NULL)
       ArgusPrintRecord (parser, &sbuf[strlen(sbuf)], ns, MAXSTRLEN - strlen(sbuf));
@@ -562,7 +571,7 @@ ArgusProcessSyslogEvent (struct ArgusParserStruct *parser, struct ArgusEventStru
 }
 
 int
-ArgusProcessFileEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *event, struct ArgusRecordStruct *ns)
+ArgusProcessFileEvent (struct ArgusParserStruct *parser, struct ArgusEventObject *event, struct ArgusRecordStruct *ns)
 {
    int retn = 0, i;
    char sbuf[MAXSTRLEN];
@@ -577,11 +586,11 @@ ArgusProcessFileEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
  
    (void) sprintf (sbuf, "%s %s[%d]: ", stimebuf, ArgusParser->ArgusProgramName, (int)getpid());
  
-   for (i = 0; i < NTAIS_NFACILITY; i++)
+   for (i = 0; i < AIS_NFACILITY; i++)
       if (RaSQLEventFacilities[i].v == event->facility)
          facility = RaSQLEventFacilities[i].s;
  
-   sprintf (&sbuf[strlen(sbuf)], "[ntais] %s:%s:'%s' ", facility, event->metadata, event->message);
+   sprintf (&sbuf[strlen(sbuf)], "[ais] %s:%s:'%s' ", facility, event->metadata, event->message);
  
    if (ns != NULL)
       ArgusPrintRecord (parser, &sbuf[strlen(sbuf)], ns, MAXSTRLEN - strlen(sbuf));
@@ -617,7 +626,7 @@ ArgusProcessFileEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
 }
 
 int
-ArgusProcessTermEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct *event, struct ArgusRecordStruct *ns)
+ArgusProcessTermEvent (struct ArgusParserStruct *parser, struct ArgusEventObject *event, struct ArgusRecordStruct *ns)
 {
    int retn = 0, i;
    char sbuf[MAXSTRLEN];
@@ -632,11 +641,11 @@ ArgusProcessTermEvent (struct ArgusParserStruct *parser, struct ArgusEventStruct
 
    (void) sprintf (sbuf, "%s %s[%d]: ", stimebuf, ArgusParser->ArgusProgramName, (int)getpid());
  
-   for (i = 0; i < NTAIS_NFACILITY; i++)
+   for (i = 0; i < AIS_NFACILITY; i++)
       if (RaSQLEventFacilities[i].v == event->facility)
          facility = RaSQLEventFacilities[i].s;
 
-   sprintf (&sbuf[strlen(sbuf)], "[ntais] %s:%s:'%s' ", facility, event->metadata, event->message);
+   sprintf (&sbuf[strlen(sbuf)], "[ais] %s:%s:'%s' ", facility, event->metadata, event->message);
 
    if (ns != NULL)
       ArgusPrintRecord (parser, &sbuf[strlen(sbuf)], ns, MAXSTRLEN - strlen(sbuf));
